@@ -76,6 +76,39 @@ int gpasm_magic(char *c)
   return c[0];
 }
 
+/*
+  convert_escaped_char(char *src,char c)
+  Input: pointer to a string
+  Output returns the input string with escaped char converted to a regular char
+
+  For example if escaped character is a double quote then:
+
+  This is a escaped quote: \"
+
+  is translated to:
+
+  This is a escaped quote: "
+
+*/
+char *
+convert_escaped_char(char *str, char c)
+{
+  char *src  = str;
+  char *dest = str;
+
+  if (!str)
+    return str;
+
+  while (*src) {
+    if (*src =='\\' && src[1] == c)
+      src++;
+    *dest++ = *src++;
+  }
+  *dest=0;
+
+  return str;
+}
+
 /* Determine the value of the escape char pointed to by ps.  Return a pointer
 to the next character. */ 
 
@@ -167,7 +200,6 @@ void set_global(char *name,
     var->value = value;
     var->coff_num = state.obj.symbol_num;
     var->coff_section_num = state.obj.section_num;
-    var->register_file = state.register_block;
     var->type = type;
     var->previous_type = type;  /* coff symbols can be changed to global */
   } else if (lifetime == TEMPORARY) {
