@@ -29,6 +29,7 @@ Boston, MA 02111-1307, USA.  */
 #include "map.h"
 
 struct gplink_state state;
+static int processor_mismatch_warning = 1;
 
 int yyparse(void);
 extern int yydebug;
@@ -57,14 +58,15 @@ void object_append(gp_object_type *file, char *name)
     
     if (file->class != state.class) {
       gp_error("processor family mismatch in \"%s\"", file->filename);
-    } else if (file->processor != state.processor) {
+    } else if ((0 != processor_mismatch_warning) &&
+               (file->processor != state.processor)) {
       gp_warning("processor mismatch in \"%s\"", file->filename);
     }
 
   }
 
   if (state.optimize.weak_symbols) {
-    gp_cofflink_remove_weak(file);
+    gp_coffopt_remove_weak(file);
   }
 
   return;
@@ -383,12 +385,14 @@ set_optimize_level(void)
 {
 
   /* default */
+  state.optimize.dead_sections = false;
   state.optimize.weak_symbols = false;
 
   switch(state.optimize.level) {
   case 3:
     /* fall through */
   case 2:
+    state.optimize.dead_sections = true;
     /* fall through */
   case 1:
     state.optimize.weak_symbols = true;
@@ -402,25 +406,26 @@ set_optimize_level(void)
   return;
 }
 
-#define GET_OPTIONS "?a:cdf:hI:lmo:O:qrs:t:v"
+#define GET_OPTIONS "?a:cdf:hI:lmo:O:qrs:t:vw"
 
   static struct option longopts[] =
   {
-    { "hex-format",  1, 0, 'a' },
-    { "object",      0, 0, 'c' },
-    { "debug",       0, 0, 'd' },
-    { "fill",        1, 0, 'f' },
-    { "help",        0, 0, 'h' },
-    { "include",     1, 0, 'I' },
-    { "no-list",     0, 0, 'l' },
-    { "map",         0, 0, 'm' },
-    { "output",      1, 0, 'o' },
-    { "optimize",    1, 0, 'O' },
-    { "quiet",       0, 0, 'q' },
-    { "use-shared",  0, 0, 'r' },
-    { "script",      1, 0, 's' },
-    { "stack",       1, 0, 't' },
-    { "version",     0, 0, 'v' },
+    { "hex-format",          1, 0, 'a' },
+    { "object",              0, 0, 'c' },
+    { "debug",               0, 0, 'd' },
+    { "fill",                1, 0, 'f' },
+    { "help",                0, 0, 'h' },
+    { "include",             1, 0, 'I' },
+    { "no-list",             0, 0, 'l' },
+    { "map",                 0, 0, 'm' },
+    { "output",              1, 0, 'o' },
+    { "optimize",            1, 0, 'O' },
+    { "quiet",               0, 0, 'q' },
+    { "use-shared",          0, 0, 'r' },
+    { "script",              1, 0, 's' },
+    { "stack",               1, 0, 't' },
+    { "version",             0, 0, 'v' },
+    { "processor-mismatch",  0, 0, 'w' },
     { 0, 0, 0, 0 }
   };
 
@@ -491,6 +496,7 @@ void show_usage(void)
   printf("  -s FILE, --script FILE         Linker script.\n");
   printf("  -t SIZE, --stack SIZE          Create a stack section.\n");
   printf("  -v, --version                  Show version.\n");
+  printf("  -w, --processor-mismatch       Disable \"processor mismatch\" warning.\n");
   printf("\n");
 #ifdef USE_DEFAULT_PATHS
   if (gp_lkr_path) {
@@ -607,6 +613,10 @@ process_args( int argc, char *argv[])
     case 'v':
       fprintf(stderr, "%s\n", GPLINK_VERSION_STRING);
       exit(0);
+      break;
+    case 'w':
+      processor_mismatch_warning = 0;
+      break;
     }
     if (usage)
       break;
@@ -643,6 +653,10 @@ process_args( int argc, char *argv[])
     gplink_add_path(gp_lib_path);
   }
 
+  if (gp_lkr_path) {
+    gplink_add_path(gp_lkr_path);
+  }
+
   /* Open all objects and archives in the file list. */ 
   for ( ; optind < argc; optind++) {
     gplink_open_coff(argv[optind]);
@@ -713,13 +727,27 @@ linker(void)
      required to resolve external references. */
   build_tables();  
 
+  /* combine all object files into one object */
+  gp_cofflink_combine_objects(state.object);
+
   /* add the stack section */
   if (state.has_stack) {
     gp_cofflink_make_stack(state.object, state.stack_size);
+    add_linker_symbol("_stack");
+    add_linker_symbol("_stack_end");
   }
 
-  /* combine all object files into one object */
-  gp_cofflink_combine_objects(state.object);
+  if (state.has_idata) {
+    gp_cofflink_make_cinit(state.object);
+    add_linker_symbol("_cinit");
+  }
+
+  /* clean up symbol table */
+  gp_cofflink_clean_table(state.object, state.symbol.definition);
+
+  if (state.optimize.dead_sections) {
+    gp_coffopt_remove_dead_sections(state.object, 0);
+  }
 
   /* combine overlay sections */
   gp_cofflink_combine_overlay(state.object, 0);
@@ -793,20 +821,8 @@ linker(void)
   i_memory_free(data);
   i_memory_free(program);
 
-  if (state.has_idata) {
-    add_linker_symbol("_cinit");
-  }
-
-  if (state.has_stack) {
-    add_linker_symbol("_stack");
-    add_linker_symbol("_stack_end");
-  }
-
   /* patch raw data with the relocated symbol values */
-  gp_cofflink_patch(state.object, state.symbol.definition);
-
-  /* clean up symbol table */
-  gp_cofflink_clean_table(state.object);
+  gp_cofflink_patch(state.object);
 
   /* modify the executable object data */
   state.object->filename = strdup(state.objfilename);
