@@ -1,5 +1,5 @@
 /* Displays contents of ".COD" files
-   Copyright (C) 2001, 2002, 2003, 2004
+   Copyright (C) 2001, 2002, 2003, 2004, 2005
    Scott Dattalo
 
 This file is part of gputils.
@@ -33,7 +33,7 @@ char *source_file_names[MAX_SOURCE_FILES];
 FILE *source_files[MAX_SOURCE_FILES];
 DirBlockInfo main_dir;
 
-int addrsize;
+int byte_addr;
 
 char directory_block_data[COD_BLOCK_SIZE];
 char * SymbolType4[154] = {
@@ -86,7 +86,7 @@ void show_usage(void)
   printf("Options: [defaults in brackets after descriptions]\n");
   printf("  -a, --all          Display all information in .cod file.\n");
   printf("  -d, --directory    Display directory header.\n");
-  printf("  -l, --listing      Display source listing cross.\n");
+  printf("  -l, --listing      Display source listing.\n");
   printf("  -m, --message      Display debug message area.\n");
   printf("  -h, --help         Show this usage message.\n");
   printf("  -r, --rom          Display rom.\n");
@@ -94,7 +94,7 @@ void show_usage(void)
   printf("  -v, --version      Show version.\n");
   printf("\n");
   printf("Report bugs to:\n");
-  printf("%s\n", BUG_REPORT_URL);
+  printf("%s\n", PACKAGE_BUGREPORT);
   exit(0);
 }
 
@@ -126,7 +126,7 @@ int main(int argc, char *argv[])
 
   gp_init();
 
-  addrsize = 1;
+  byte_addr = 0;
 
 #define DISPLAY_NOTHING 0
 #define DISPLAY_DIR     1
